==> hvcg_academics_openapi_student-0.7.0.crate: hvcg_academics_openapi_student-0.7.0/docs/StudentUpsert.md <==
# StudentUpsert

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**polity_id** | [***uuid::Uuid**](UUID.md) |  | [optional] [default to None]
**saint_id_array** | [**Vec<uuid::Uuid>**](UUID.md) |  | [optional] [default to None]
**title** | [***models::StudentTitle**](StudentTitle.md) |  | [optional] [default to None]
**progress** | [***models::VowProgress**](VowProgress.md) |  | [optional] [default to None]
**first_name** | **String** |  | [optional] [default to None]
**middle_name** | **String** |  | [optional] [default to None]
**last_name** | **String** |  | [optional] [default to None]
**date_of_birth** | [***NaiveDate**](date.md) | date of birth in format YYYY-MM-DD | [optional] [default to None]
**place_of_birth** | **String** |  | [optional] [default to None]
**email** | **String** |  | [optional] [default to None]
**phone** | **String** |  | [optional] [default to None]
**address** | **String** |  | [optional] [default to None]
**undergraduate_school** | **String** |  | [optional] [default to None]
**nationality** | **String** |  | [optional] [default to Some("Vietnamese".to_string())]
**educational_stage** | [***models::EducationalStage**](EducationalStage.md) |  | [optional] [default to None]
**race** | **String** |  | [optional] [default to None]
**program_id** | [***uuid::Uuid**](UUID.md) |  | [optional] [default to None]
**is_male** | **bool** |  | [optional] [default to Some(true)]
**national_id** | **String** |  | [optional] [default to None]
**passport** | **String** |  | [optional] [default to None]
**date_of_issue** | [***NaiveDate**](date.md) |  | [optional] [default to None]
**place_of_issue** | [***NaiveDate**](date.md) |  | [optional] [default to None]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> hvcg_academics_openapi_student-0.8.0.crate: hvcg_academics_openapi_student-0.8.0/docs/StudentUpsert.md <==
# StudentUpsert

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**polity_id** | [***uuid::Uuid**](UUID.md) |  | [optional] [default to None]
**saint_id_array** | [**Vec<uuid::Uuid>**](UUID.md) |  | [optional] [default to None]
**title** | [***models::StudentTitle**](StudentTitle.md) |  | [optional] [default to None]
**progress** | [***models::VowProgress**](VowProgress.md) |  | [optional] [default to None]
**first_name** | **String** |  | [optional] [default to None]
**middle_name** | **String** |  | [optional] [default to None]
**last_name** | **String** |  | [optional] [default to None]
**date_of_birth** | [***NaiveDate**](date.md) | date of birth in format YYYY-MM-DD | [optional] [default to None]
**place_of_birth** | **String** |  | [optional] [default to None]
**email** | **String** |  | [optional] [default to None]
**phone** | **String** |  | [optional] [default to None]
**address** | **String** |  | [optional] [default to None]
**nationality** | **String** |  | [optional] [default to Some("Vietnamese".to_string())]
**educational_stage** | [**Vec<models::EducationalStage>**](EducationalStage.md) |  | [optional] [default to None]
**foreign_language** | [**Vec<models::ForeignLanguage>**](ForeignLanguage.md) |  | [optional] [default to None]
**race** | **String** |  | [optional] [default to None]
**program_id** | [***uuid::Uuid**](UUID.md) |  | [optional] [default to None]
**id_number** | **String** |  | [optional] [default to None]
**id_number_provider** | [***models::IdNumberProvider**](IdNumberProvider.md) |  | [optional] [default to None]
**passport** | **String** |  | [optional] [default to None]
**date_of_issue** | [***NaiveDate**](date.md) |  | [optional] [default to None]
**place_of_issue** | **String** |  | [optional] [default to None]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
